@@ -37,9 +37,7 @@
 #include "DlAbortEx.h"
 #include "HandshakeExtensionMessage.h"
 #include "UTPexExtensionMessage.h"
-#include "LogFactory.h"
-#include "Logger.h"
-#include "StringFormat.h"
+#include "fmt.h"
 #include "PeerStorage.h"
 #include "ExtensionMessageRegistry.h"
 #include "DownloadContext.h"
@@ -56,15 +54,18 @@
 
 namespace aria2 {
 
-DefaultExtensionMessageFactory::DefaultExtensionMessageFactory():
-  logger_(LogFactory::getInstance()) {}
+DefaultExtensionMessageFactory::DefaultExtensionMessageFactory()
+  : messageFactory_(0),
+    dispatcher_(0),
+    tracker_(0)
+{}
 
 DefaultExtensionMessageFactory::DefaultExtensionMessageFactory
 (const SharedHandle<Peer>& peer,
- const SharedHandle<ExtensionMessageRegistry>& registry):
-  peer_(peer),
-  registry_(registry),
-  logger_(LogFactory::getInstance()) {}
+ const SharedHandle<ExtensionMessageRegistry>& registry)
+  : peer_(peer),
+    registry_(registry)
+{}
 
 DefaultExtensionMessageFactory::~DefaultExtensionMessageFactory() {}
 
@@ -83,8 +84,8 @@ DefaultExtensionMessageFactory::createMessage(const unsigned char* data, size_t
     std::string extensionName = registry_->getExtensionName(extensionMessageID);
     if(extensionName.empty()) {
       throw DL_ABORT_EX
-        (StringFormat("No extension registered for extended message ID %u",
-                      extensionMessageID).str());
+        (fmt("No extension registered for extended message ID %u",
+             extensionMessageID));
     }
     if(extensionName == "ut_pex") {
       // uTorrent compatible Peer-Exchange
@@ -94,8 +95,10 @@ DefaultExtensionMessageFactory::createMessage(const unsigned char* data, size_t
       return m;
     } else if(extensionName == "ut_metadata") {
       if(length == 0) {
-        throw DL_ABORT_EX(StringFormat(MSG_TOO_SMALL_PAYLOAD_SIZE,
-                                       "ut_metadata", length).str());
+        throw DL_ABORT_EX
+          (fmt(MSG_TOO_SMALL_PAYLOAD_SIZE,
+               "ut_metadata",
+               static_cast<unsigned long>(length)));
       }
       size_t end;
       SharedHandle<ValueBase> decoded = bencode2::decode(data+1, length-1, end);
@@ -148,14 +151,15 @@ DefaultExtensionMessageFactory::createMessage(const unsigned char* data, size_t
         return m;
       }
       default:
-        throw DL_ABORT_EX(StringFormat("Bad ut_metadata: unknown msg_type=%u",
-                                       msgType->i()).str());
+        throw DL_ABORT_EX
+          (fmt("Bad ut_metadata: unknown msg_type=%u",
+               static_cast<unsigned int>(msgType->i())));
       }
     } else {
       throw DL_ABORT_EX
-        (StringFormat("Unsupported extension message received."
-                      " extensionMessageID=%u, extensionName=%s",
-                      extensionMessageID, extensionName.c_str()).str());
+        (fmt("Unsupported extension message received."
+             " extensionMessageID=%u, extensionName=%s",
+             extensionMessageID, extensionName.c_str()));
     }
   }
 }
