@@ -32,20 +32,23 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_METALINK_PARSER_CONTROLLER_H_
-#define _D_METALINK_PARSER_CONTROLLER_H_
+#ifndef D_METALINK_PARSER_CONTROLLER_H
+#define D_METALINK_PARSER_CONTROLLER_H
 
 #include "common.h"
-#include "SharedHandle.h"
+
 #include <string>
 #include <utility>
-#include <deque>
+#include <vector>
+
+#include "SharedHandle.h"
 
 namespace aria2 {
 
 class Metalinker;
 class MetalinkEntry;
 class MetalinkResource;
+class MetalinkMetaurl;
 class Signature;
 
 #ifdef ENABLE_MESSAGE_DIGEST
@@ -55,25 +58,30 @@ class ChunkChecksum;
 
 class MetalinkParserController {
 private:
-  SharedHandle<Metalinker> _metalinker;
+  SharedHandle<Metalinker> metalinker_;
 
-  SharedHandle<MetalinkEntry> _tEntry;
+  SharedHandle<MetalinkEntry> tEntry_;
 
-  SharedHandle<MetalinkResource> _tResource;
+  SharedHandle<MetalinkResource> tResource_;
 
+  SharedHandle<MetalinkMetaurl> tMetaurl_;
 #ifdef ENABLE_MESSAGE_DIGEST
-  SharedHandle<Checksum> _tChecksum;
+  SharedHandle<Checksum> tChecksum_;
 
-  SharedHandle<ChunkChecksum> _tChunkChecksum;
+  SharedHandle<ChunkChecksum> tChunkChecksumV4_; // Metalink4Spec
+
+  std::vector<std::string> tempChunkChecksumsV4_; // Metalink4Spec
+
+  SharedHandle<ChunkChecksum> tChunkChecksum_; // Metalink3Spec
+
+  std::vector<std::pair<size_t, std::string> > tempChunkChecksums_;//Metalink3Spec
+
+  std::pair<size_t, std::string> tempHashPair_; // Metalink3Spec
 
-  std::deque<std::pair<size_t, std::string> > _tempChunkChecksums;
-  
-  std::pair<size_t, std::string> _tempHashPair;
 #endif // ENABLE_MESSAGE_DIGEST
 
-  SharedHandle<Signature> _tSignature;
-
-  static const std::string SHA1;
+  SharedHandle<Signature> tSignature_;
+  std::string baseUri_;
 public:
   MetalinkParserController();
 
@@ -81,7 +89,7 @@ public:
 
   const SharedHandle<Metalinker>& getResult() const
   {
-    return _metalinker;
+    return metalinker_;
   }
 
   void newEntryTransaction();
@@ -110,7 +118,7 @@ public:
 
   void setLocationOfResource(const std::string& location);
 
-  void setPreferenceOfResource(int preference);
+  void setPriorityOfResource(int priority);
 
   void setMaxConnectionsOfResource(int maxConnections);
 
@@ -127,24 +135,36 @@ public:
   void commitChecksumTransaction();
 
   void cancelChecksumTransaction();
-  
-  void newChunkChecksumTransaction();
 
-  void setTypeOfChunkChecksum(const std::string& type);
+  void newChunkChecksumTransactionV4(); // Metalink4Spec
 
-  void setLengthOfChunkChecksum(size_t length);
+  void setTypeOfChunkChecksumV4(const std::string& type); // Metalink4Spec
 
-  void addHashOfChunkChecksum(size_t order, const std::string& md);
+  void setLengthOfChunkChecksumV4(size_t length); // Metalink4Spec
 
-  void createNewHashOfChunkChecksum(size_t order);
+  void addHashOfChunkChecksumV4(const std::string& md); // Metalink4Spec
 
-  void setMessageDigestOfChunkChecksum(const std::string& md);
+  void commitChunkChecksumTransactionV4(); // Metalink4Spec
 
-  void addHashOfChunkChecksum();
+  void cancelChunkChecksumTransactionV4(); // Metalink4Spec
 
-  void commitChunkChecksumTransaction();
+  void newChunkChecksumTransaction(); // Metalink3Spec
 
-  void cancelChunkChecksumTransaction();
+  void setTypeOfChunkChecksum(const std::string& type); // Metalink3Spec
+
+  void setLengthOfChunkChecksum(size_t length); // Metalink3Spec
+
+  void addHashOfChunkChecksum(size_t order, const std::string& md);// Metalink3Spec
+
+  void createNewHashOfChunkChecksum(size_t order); // Metalink3Spec
+
+  void setMessageDigestOfChunkChecksum(const std::string& md); // Metalink3Spec
+
+  void addHashOfChunkChecksum(); // Metalink3Spec
+
+  void commitChunkChecksumTransaction(); // Metalink3Spec
+
+  void cancelChunkChecksumTransaction(); // Metalink3Spec
 
   void newSignatureTransaction();
 
@@ -157,8 +177,27 @@ public:
   void commitSignatureTransaction();
 
   void cancelSignatureTransaction();
+
+  void newMetaurlTransaction();
+
+  void setURLOfMetaurl(const std::string& url);
+
+  void setMediatypeOfMetaurl(const std::string& mediatype);
+
+  void setPriorityOfMetaurl(int priority);
+
+  void setNameOfMetaurl(const std::string& name);
+
+  void commitMetaurlTransaction();
+
+  void cancelMetaurlTransaction();
+
+  void setBaseUri(const std::string& baseUri)
+  {
+    baseUri_ = baseUri;
+  }
 };
 
 } // namespace aria2
 
-#endif // _D_METALINK_PARSER_CONTROLLER_H_
+#endif // D_METALINK_PARSER_CONTROLLER_H
