@@ -6,6 +6,8 @@
 #include "Option.h"
 #include "DownloadContext.h"
 #include "FileEntry.h"
+#include "PieceStorage.h"
+#include "DiskAdaptor.h"
 
 namespace aria2 {
 
@@ -15,6 +17,7 @@ class MetalinkPostDownloadHandlerTest:public CppUnit::TestFixture {
   CPPUNIT_TEST(testCanHandle_extension);
   CPPUNIT_TEST(testCanHandle_contentType);
   CPPUNIT_TEST(testGetNextRequestGroups);
+  CPPUNIT_TEST(testGetNextRequestGroups_withBaseUri);
   CPPUNIT_TEST_SUITE_END();
 private:
   SharedHandle<Option> option_;
@@ -27,6 +30,7 @@ public:
   void testCanHandle_extension();
   void testCanHandle_contentType();
   void testGetNextRequestGroups();
+  void testGetNextRequestGroups_withBaseUri();
 };
 
 
@@ -65,10 +69,11 @@ void MetalinkPostDownloadHandlerTest::testCanHandle_contentType()
 void MetalinkPostDownloadHandlerTest::testGetNextRequestGroups()
 {
   SharedHandle<DownloadContext> dctx
-    (new DownloadContext(1024, 0, "test.xml"));
+    (new DownloadContext(1024, 0, A2_TEST_DIR"/test.xml"));
   RequestGroup rg(option_);
   rg.setDownloadContext(dctx);
   rg.initPieceStorage();
+  rg.getPieceStorage()->getDiskAdaptor()->enableReadOnly();
 
   MetalinkPostDownloadHandler handler;
   std::vector<SharedHandle<RequestGroup> > groups;
@@ -80,4 +85,23 @@ void MetalinkPostDownloadHandlerTest::testGetNextRequestGroups()
 #endif // ENABLE_BITTORRENT
 }
 
+void MetalinkPostDownloadHandlerTest::testGetNextRequestGroups_withBaseUri()
+{
+  SharedHandle<DownloadContext> dctx
+    (new DownloadContext(1024, 0, A2_TEST_DIR"/base_uri.xml"));
+  dctx->getFirstFileEntry()->addUri("http://base/dir/base_uri.xml");
+  RequestGroup rg(option_);
+  rg.setDownloadContext(dctx);
+  rg.initPieceStorage();
+  rg.getPieceStorage()->getDiskAdaptor()->enableReadOnly();
+
+  MetalinkPostDownloadHandler handler;
+  std::vector<SharedHandle<RequestGroup> > groups;
+  handler.getNextRequestGroups(groups, &rg);
+  CPPUNIT_ASSERT_EQUAL((size_t)1, groups.size());
+  CPPUNIT_ASSERT_EQUAL(std::string("http://base/dir/example.ext"),
+                       groups[0]->getDownloadContext()->
+                       getFirstFileEntry()->getRemainingUris()[0]);
+}
+
 } // namespace aria2
